// Copyright (C) 2006-2013 Xilinx, Inc.  All rights reserved
// $Id: ArgParser.h,v 1.27.206.2 2013/05/10 00:04:05 jcorbett Exp $
//
// Parse command line arguments, issue usage message, report
// parameters, load data files, load a text file with net names
// that are not required to be isolated, save a text file with net
// names that appear in multiple groups, and report elapsed time.

// R#accept_isolation_regions, R#report_errors, R#report_provenance

#ifndef Iv_ArgParser_h
#define Iv_ArgParser_h

#include "Portability/export/basutcmdarg.h"
#include "Portability/export/basuttime.h"

#include <string>
#include <fstream>
#include <sstream>
#include <map>

#include "Data.h"

// Class to parse the command line arguments, report them, and store
// them in a checker, for it to process.
class ArgParser {
public:
   ArgParser(int argc, const char * const * argv, Data& data);
   void ReportHeader();
   bool NeedPinCheck();
   bool NeedConstraintsCheck();
   bool NeedPathAnalysis();
   void ReportFooter();
   void static CloseFiles();
public:
   static std::ofstream reportOut;
   static std::ostringstream errorBuf;
   static std::ostream* errorOut;
   static std::ostringstream summaryBuf;
   static std::ofstream drawingOut;
   static bool verbose;
   static bool allPaths;
   static unsigned sectionNumber;
   static unsigned subsectionNumber;
private:
   const std::string SupportedArchitectures() const;
   void LoadScript(const char* scriptPath);
   void LoadPinIsolationGroupsTxt(const char* pigPath);
   int GroupCount();
private:
   Data& data;
   UT_CMDARGS cmdArgs;
   UT_TIME::Clock_t startTime;
   std::string outFile;
   std::string pigFile;         // pin isolation group file
};

#endif
