// Copyright (C) 2009-2010 Xilinx, Inc.  All rights reserved
// $Id: ColorTable.h,v 1.2 2010/11/08 19:03:09 jcorbett Exp $

#ifndef Iv_ColorTable_h
#define Iv_ColorTable_h

// The table below is an ordered mapping from color names to CSS color
// codes used in SVG graphics. Each code consists of three pairs of
// hex digits representing the intensity of red, green, and blue
// respectively. #000000 is black. #ff0000 is pure red. Etc.
//
// The colors have been selected to represent common usage, to be
// easily distinguished by most viewers and on most displays, and to
// provide sufficient contrast as a background for black text.

typedef struct {
   const char* colorName;       // Presentable name
   const char* colorCode;       // Code for SVG fill-color, etc.
} ColorName_RgbCode;

ColorName_RgbCode colorTable[] = {
   { "White",           "#ffffff" },
   { "Orange",          "#ffa102" },
   { "Red",             "#ff0000" },
   { "Green",           "#08d308" },

   { "Gray",            "#888888" },
   { "Red",             "#e10000" },
   { "Blue",            "#3030f0" },
   { "Yellow",          "#ffda44" },
   { "Blue Green",      "#008888" },
   { "Violet",          "#5b008e" },

   { "Light Gray",      "#bebebe" },
   { "Pink",            "#fe7777" },
   { "Light Blue",      "#8080fe" },
   { "Light Yellow",    "#feeda8" },
   { "Light Orange",    "#fec565" },
   { "Cyan",            "#00ecec" },
   { "Light Green",     "#40fc40" },
   { "Purple",          "#9a00f2" },

   { "Dark Gray",       "#685555" },
   { "Dark Red",        "#a50000" },
   { "Dark Blue",       "#000097" },
   { "Dark Yellow",     "#c4a426" },
   { "Dark Blue Green", "#005959" },
   { "Dark Orange",     "#bb7600" },
   { "Dark Green",      "#009e00" },
   { "Dark Violet",     "#420068" }
};

const unsigned long ColorName_Blank(0);
const unsigned long ColorName_Mixed(1);
const unsigned long ColorName_Violation(2);
const unsigned long ColorName_Global(3);
const unsigned long ColorName_User(4);
const unsigned long ColorName_Size(sizeof colorTable / sizeof colorTable[0]);
const unsigned long ColorName_Overflow(ColorName_Size - 1);

#endif
