// Copyright (C) 2006-2011 Xilinx, Inc.  All rights reserved
// $Id: NetChecker.h,v 1.24 2011/03/04 02:05:28 jcorbett Exp $
//
// R#report_interregion_signals - Explore potential routes through
// unrouted portions of a Virtex-4 device that could leak information
// from one isolated region to another.

#ifndef Iv_NetChecker_h
#define Iv_NetChecker_h

#include <map>
#include <set>
#include <string>

#include "CadFile.h"
#include "Data.h"
#include "RevArc.h"
#include "ArcCost.h"

// Class to check ncd files for isolation faults.
// Relies on ArgParser to initialize NetChecker::groupData.
class NetChecker {

private:
   typedef std::map<Rf_Node, XCad_CadNetwork*> NodeNet;
   typedef NodeNet::iterator NodeIt;

   typedef
   std::multimap<Data::NetPair, Data::ArcPath, Data::NetPairLess > NetPath;
   typedef NetPath::iterator PathIt;

public:
   NetChecker(Data& cadData);
   ~NetChecker() {}
   // Search from every arc in every net except the "ignored" ones.
   void Check();
   void ReportFaults(bool verbose);
   int GetStatus();
   int GetErrorCount();
   void AnalyzePath();
private:
   void ReportUnroutedNets();

   // Label the nodes from the user's groups.
   void LabelNodes();

   void CheckArcToNet(RevArc& arc, XCad_CadNetwork* net);
   void CheckArcToArc(Data::ArcPath& path);
   void AddFault(XCad_CadNetwork* startNet,
                 XCad_CadNetwork* endNet,
                 Data::ArcPath& path);
   void DepthLimitedSearch(XCad_CadNetwork* startNet,
                           RevArc arc,
                           const std::string& group,
                           const int cost,
                           Data::ArcPath& path);
   void ReportArc(RevArc arc);
   void ReportFault(XCad_CadNetwork* startNet,
                    XCad_CadNetwork* endNet,
                    Data::ArcPath& path);
   Rf_Node GetRoutedNodeByName(const char* name);
   Rf_Arc GetArcFromNodeAndWireName(Rf_Node node, Port_String wireName);
   XCad_CadNetwork* GetNetByNode(Rf_Node node);
   void AnalyzePathForward();
   void AnalyzePathReverse();
private:
   boost::shared_ptr<ArcCost> costFunction;
   Data& data;
   NodeNet nodeNet;
   NetPath faultList;
   int faultCount;
   int pathCount;                // all paths, not just faulty ones

   typedef std::map<Rf_Node, int> NodeCostMap;
   NodeCostMap prevCost;         // node -> cost of shortest route so far

   std::string* group1;          // used for report headings
   std::string* group2;          // used for report headings
};

#endif
