#! cd .
# $Id: make.t,v 1.24.206.6 2015/01/05 18:04:28 jcorbett Exp $
#
# Copyright (c) 2006-2010 Xilinx Inc.
# All rights reserved
#

# The product will be "ISE" for the forseeable future and it is hard
# coded into the script that generates CurrentBuild.h anyway.
REL_PROD := ISE

# If the service pack is defined, prepend a dot to it.
SSP := $(if ${SOFTWARE_SERVICE_PACK},.${SOFTWARE_SERVICE_PACK},)

# The product version, e.g. "12.3".
REL_VER := ${SOFTWARE_MAJOR_VERSION}.${SOFTWARE_MINOR_VERSION}${SSP}

# The following two regular expressions control supported devices.
# Note: take care to quote these variables, otherwise the vertical
# bars might get interpreted prematurely.

# ARCH_PAT is used to filter partgen output.
# # ARCH_PAT := virtex[4567]|spartan6|kintex7|artix7
# DEV_PAT is used to perform an early sanity check in both UCF- and
# NCD-mode.
#
# Note: there is no automatic check that DEV_PAT and ARCH_PAT
# match. (Hopefully putting them right next to each other will do.)
ARCH_PAT := \w*(virtex[4567]|spartan6|kintex7|artix7|zynq)\w*
DEV_PAT := .*(4v|5v|6v|6s|7[akvz]).*


all: descenv
!Subbld s

# Development build target. This one assumes version.inc and
# device.inc are writable.
devbld: descenv gendev incver
!Subbld s

# Increment the version number and collect the version information in
# version.inc.
incver:
	${PERL} incver.pl ${SOFTWARE_VERSION} ${REL_PROD} ${REL_VER}

# When automatically building ivt for multiple releases of ISE, the
# supported devices may differ from one release to the next. Normally,
# this change would cause the ivt version generated by incver to
# change, but since the ivt source (except for the
# automatically-generated device list) is identical, it would be
# confusing to change versions in mid-stream, so to speak.  To address
# this, the version is set through the FORCE_VER environment variable
# in the script that drives the multi-release build.
forcever:
	${PERL} incver.pl ${SOFTWARE_VERSION} ${REL_PROD} ${REL_VER} \
		${FORCE_VER}


# Use partgen to generate a list of architecture names and device names.
gendev:
	@@[ -w i/device.inc ] && \
	gendevicelist.bash "${ARCH_PAT}" "${DEV_PAT}" > i/device.inc && \
        ${ECHO} "Generated device list for ${ARCH_PAT}." || \
	${ECHO} "WARNING: Unable to update i/device.inc"

# Check for development code that should not be released.
doh:
!X nt nt64
	@@${GREP} -q -i '#if \|xxx' s/*.c i/*.h && \
	(echo;echo '# WARNING: Contains commented code!';echo;true) || \
         (echo "No commented out code.")

libs:

objs:
!Subbld s

dbglibs:

rellibs:

libexecs:
!Subbld s

toolrel:
!Subbld s

etags:
	@@${ECHO};${ECHO} "Rebuilding tags..."
	@@etags s/*.c i/*.h

######################################################################
# List all includes sorted without duplicates.
allinc:
!X nt nt64
	@@${GREP} --no-filename "#include" s/*.c i/*.h \
            | ${SORT} | ${UNIQ}

# List all Xilinx library includes sorted without duplicates. Xilinx
# include files are recognized by looking for a path
# separator surrounded by "word" characters.
xilinc:
!X nt nt64
	@@${GREP} --no-filename "#include.*\w/\w" s/*.c i/*.h \
            | ${SORT} | ${UNIQ}

# Create a bzip2 tar archive of all the include files.
alldeps:
!X nt nt64
!Subbld s

# List external symbols. GNU only.
exsyms:
	(export LD_LIBRARY_PATH='';nm -C -u lin64opt/ivt)

# Copy all sources and headers into a stand alone archive.

# Standalone source archive directory, e.g. ivt_src_5_07a.
!X nt nt64
IVT_VER := \
  $(shell ${GREP} "version\[\]" version.inc | \
          ${GREP} --only-match '[[:digit:]]*\.[[:digit:]]*\w*' | \
          ${TR} . _)
SA := release/ivt_src_${IVT_VER}

srcrelease: alldeps
!X nt nt64
	${ECHO} PWD='${PWD}'
	${ECHO} SA='${SA}'
	${RM} -rf ${SA}
	${MKDIR} ${SA}/s ${SA}/i
	${CP} s/*.c ${SA}/s
	${CP} i/*.h ${SA}/i
	${CP} make.* ${SA}
	${CP} version.inc ${SA}
	${CP} ivt_includes.tbz ${SA}
	${CP} debug_build_lin64.log ${SA}
	${CP} doc/src_readme.txt ${SA}/README.txt

# Report the ISE version to build against.
descenv:
	@@${ECHO} ISE Build: ${SOFTWARE_VERSION}
	@@${ECHO} ISE Release: ${REL_PROD} ${REL_VER}

BACKUP := backup/`date +%F`_${IVT_VER}

# Take a snapshot of my sandbox.
backup: ${BACKUP}

${BACKUP}:
	${MKDIR} ${BACKUP}/{i,s}
	${CP} s/*.{c,t} ${BACKUP}/s
	${CP} i/*.h ${BACKUP}/i
	${CP} make.* version.inc incver.pl ${BACKUP}

release:

release0:

libsmoke:
!Subbld smoke
	@${RM} smoketest.sum
	@${XTESTSUMMARY} -r=smoke

unittest:
!Subbld unit
	@${RM} unittest.sum
	@${XTESTSUMMARY} -r=unit

regressiontest:
!Subbld test
	@${RM} regressiontest.sum
	@${XTESTSUMMARY} -r=regression

clean:
	${RMDIR} emake_data lin linopt nt ntopt lin64 lin64opt nt64 nt64opt
	${RM} make.*lin make.*nt
!Subbld s smoke unit regression

empty:
!Subbld s smoke unit regression
